@@ -104,18 +104,17 @@ def delete_wallets_page():
     delete_current_wallet()
     return jsonify(print_wallets())
 
-
-@app.route("/send/coin/<address>/<amount>/<password>", methods=["GET"])
+@app.route("/send_old/coin/<address>/<amount>/<password>", methods=["GET"])
 def send_coin_page(address, amount, password):
     logger.info(
         f"{request.remote_addr} {request.method} {request.url} {request.data}")
     block = (GetBlock(custom_TEMP_BLOCK_PATH=custom_TEMP_BLOCK_PATH)
              if custom_block is None else custom_block)
     send_tx = send(
-        block,
         password,
         address,
-        amount,
+        amount=amount,
+        block=block,
         custom_current_time=custom_current_time,
         custom_sequence_number=custom_sequence_number,
         custom_balance=custom_balance,
@@ -140,19 +139,24 @@ def send_coin_page(address, amount, password):
     return jsonify(result)
 
 
-@app.route("/send/coin-data/<address>/<amount>/<data>/<password>",
-           methods=["GET"])
-def send_coin_data_page(address, amount, data, password):
+
+@app.route("/send/",
+           methods=["POST"])
+def send_coin_data_page():
     logger.info(
-        f"{request.remote_addr} {request.method} {request.url} {request.data}")
+        f"{request.remote_addr} {request.method} {request.url} {request.form}")
+    address = str(request.form["to_user"]) if "to_user" in request.form else None
+    amount = float(request.form["amount"]) if "amount" in request.form else None
+    data = str(request.form["data"]) if "data" in request.form else None
+    password = str(request.form["password"]) if "password" in request.form else None      
     block = (GetBlock(custom_TEMP_BLOCK_PATH=custom_TEMP_BLOCK_PATH)
              if custom_block is None else custom_block)
     send_tx = send(
-        block,
         password,
         address,
-        amount,
+        amount=amount,
         data=data,
+        block=block,
         custom_current_time=custom_current_time,
         custom_sequence_number=custom_sequence_number,
         custom_balance=custom_balance,
