@@ -9,7 +9,6 @@ import os
 
 from decentra_network.config import TEMP_BLOCKSHASH_PART_PATH
 from decentra_network.config import TEMP_BLOCKSHASH_PATH
-from decentra_network.lib.cache import Cache
 from decentra_network.lib.config_system import get_config
 from decentra_network.lib.log import get_logger
 
@@ -52,20 +51,14 @@ def GetBlockshash(custom_TEMP_BLOCKSHASH_PATH=None):
                                 if custom_TEMP_BLOCKSHASH_PATH is None else
                                 custom_TEMP_BLOCKSHASH_PATH)
 
-    the_cache = Cache.get(the_TEMP_BLOCKSHASH_PATH)
-    if the_cache is None:
-        os.chdir(get_config()["main_folder"])
-        if not os.path.exists(the_TEMP_BLOCKSHASH_PATH):
-            result = []
-            Cache.save(the_TEMP_BLOCKSHASH_PATH, result)
-            return result
+    os.chdir(get_config()["main_folder"])
+    if not os.path.exists(the_TEMP_BLOCKSHASH_PATH):
+        result = []
+        return result
 
-        with open(the_TEMP_BLOCKSHASH_PATH, "r") as block_file:
-            result = json.load(block_file)
-            Cache.save(the_TEMP_BLOCKSHASH_PATH, result)
-            return result
-    else:
-        return the_cache
+    with open(the_TEMP_BLOCKSHASH_PATH, "r") as block_file:
+        result = json.load(block_file)
+        return result
 
 
 def GetBlockshash_part(custom_TEMP_BLOCKSHASH_PART_PATH=None):
@@ -76,17 +69,11 @@ def GetBlockshash_part(custom_TEMP_BLOCKSHASH_PART_PATH=None):
                                      custom_TEMP_BLOCKSHASH_PART_PATH is None
                                      else custom_TEMP_BLOCKSHASH_PART_PATH)
 
-    the_cache = Cache.get(the_TEMP_BLOCKSHASH_PART_PATH)
-    if the_cache is None:
-        os.chdir(get_config()["main_folder"])
-        if not os.path.exists(the_TEMP_BLOCKSHASH_PART_PATH):
-            result = []
-            Cache.save(the_TEMP_BLOCKSHASH_PART_PATH, result)
-            return result
+    os.chdir(get_config()["main_folder"])
+    if not os.path.exists(the_TEMP_BLOCKSHASH_PART_PATH):
+        result = []
+        return result
 
-        with open(the_TEMP_BLOCKSHASH_PART_PATH, "r") as block_file:
-            result = json.load(block_file)
-            Cache.save(the_TEMP_BLOCKSHASH_PART_PATH, result)
-            return result
-    else:
-        return the_cache
+    with open(the_TEMP_BLOCKSHASH_PART_PATH, "r") as block_file:
+        result = json.load(block_file)
+        return result
